Documentation
¶
Overview ¶
Package fstest provides utilities for testing the Fs
Index ¶
- Variables
- func CheckItems(t *testing.T, f fs.Fs, items ...Item)
- func CheckListing(t *testing.T, f fs.Fs, items []Item)
- func CheckListingWithPrecision(t *testing.T, f fs.Fs, items []Item, expectedDirs []string, ...)
- func CheckTimeEqualWithPrecision(t0, t1 time.Time, precision time.Duration) (time.Duration, bool)
- func LocalRemote() (path string, err error)
- func RandomRemote(remoteName string, subdir bool) (fs.Fs, string, func(), error)
- func RandomRemoteName(remoteName string) (string, string, error)
- func RandomString(n int) string
- func TestMkdir(t *testing.T, remote fs.Fs)
- func TestPurge(t *testing.T, remote fs.Fs)
- func TestRmdir(t *testing.T, remote fs.Fs)
- func Time(timeString string) time.Time
- type Item
- type Items
Constants ¶
This section is empty.
Variables ¶
var ( // MatchTestRemote matches the remote names used for testing MatchTestRemote = regexp.MustCompile(`^rclone-test-[abcdefghijklmnopqrstuvwxyz0123456789]{24}$`) // ListRetries is the number of times to retry a listing to overcome eventual consistency ListRetries = flag.Int("list-retries", 6, "Number or times to retry listing") )
Functions ¶
func CheckItems ¶
CheckItems checks the fs to see if it has only the items passed in using a precision of fs.Config.ModifyWindow
func CheckListing ¶
CheckListing checks the fs to see if it has the expected contents
func CheckListingWithPrecision ¶
func CheckListingWithPrecision(t *testing.T, f fs.Fs, items []Item, expectedDirs []string, precision time.Duration)
CheckListingWithPrecision checks the fs to see if it has the expected contents with the given precision.
If expectedDirs is non nil then we check those too. Note that no directories returned is also OK as some remotes don't return directories.
func CheckTimeEqualWithPrecision ¶
CheckTimeEqualWithPrecision checks the times are equal within the precision, returns the delta and a flag
func LocalRemote ¶
LocalRemote creates a temporary directory name for local remotes
func RandomRemote ¶
RandomRemote makes a random bucket or subdirectory on the remote
Call the finalise function returned to Purge the fs at the end (and the parent if necessary)
Returns the remote, its url, a finaliser and an error
func RandomRemoteName ¶
RandomRemoteName makes a random bucket or subdirectory name
Returns a random remote name plus the leaf name
func RandomString ¶
RandomString create a random string for test purposes
Types ¶
type Item ¶
type Item struct {
Path string
Hashes map[fs.HashType]string
ModTime time.Time
Size int64
WinPath string
}
Item represents an item for checking
func (*Item) CheckHashes ¶
CheckHashes checks all the hashes the object supports are correct